package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.DataRecord;

/**
 * 外链扫描情况记录Service接口
 * 
 * @author ruoyi
 * @date 2024-09-29
 */
public interface IDataRecordService
{
    /**
     * 查询外链扫描情况记录
     * 
     * @param id 外链扫描情况记录主键
     * @return 外链扫描情况记录
     */
    public DataRecord selectDataRecordById(Long id);

    /**
     * 查询外链扫描情况记录列表
     * 
     * @param dataRecord 外链扫描情况记录
     * @return 外链扫描情况记录集合
     */
    public List<DataRecord> selectDataRecordList(DataRecord dataRecord);

    /**
     * 新增外链扫描情况记录
     * 
     * @param dataRecord 外链扫描情况记录
     * @return 结果
     */
    public int insertDataRecord(DataRecord dataRecord);

    /**
     * 修改外链扫描情况记录
     * 
     * @param dataRecord 外链扫描情况记录
     * @return 结果
     */
    public int updateDataRecord(DataRecord dataRecord);

    /**
     * 批量删除外链扫描情况记录
     * 
     * @param ids 需要删除的外链扫描情况记录主键集合
     * @return 结果
     */
    public int deleteDataRecordByIds(String ids);

    /**
     * 删除外链扫描情况记录信息
     * 
     * @param id 外链扫描情况记录主键
     * @return 结果
     */
    public int deleteDataRecordById(Long id);

    public List<DataRecord> selectDataRecordAllList(DataRecord dataRecord);

    public List<DataRecord> selectWlDataRecordAllList(DataRecord dataRecord);
}
